<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * A Font Icon select box.
 *
 * @property array $icons   A list of font-icon classes. [ 'class-name' => 'nicename', ... ]
 *                          Default Font Awesome icons. @see Control_Icon::get_icons().
 * @property array $include list of classes to include form the $icons property
 * @property array $exclude list of classes to exclude form the $icons property
 *
 * @since 1.0.0
 */
class VINKMAG_Icon_Controler extends Elementor\Base_Data_Control {

	public function get_type() {
		return 'icon';
	}

	/**
	 * Get icons list
	 *
	 * @return array
	 */

	public static function get_icons() {

		$icons = array(
                'xsicon xsicon-angle-down' => 'xsicon xsicon-angle-down',
                'xsicon xsicon-angle-left' => 'xsicon xsicon-angle-left',
                'xsicon xsicon-angle-right' => 'xsicon xsicon-angle-right',
                'xsicon xsicon-angle-up' => 'xsicon xsicon-angle-up',
                'xsicon xsicon-arrow-down' => 'xsicon xsicon-arrow-down',
                'xsicon xsicon-arrow-left' => 'xsicon xsicon-arrow-left',
                'xsicon xsicon-arrow-right' => 'xsicon xsicon-arrow-right',
                'xsicon xsicon-arrow-up' => 'xsicon xsicon-arrow-up',
                'xsicon xsicon-bolt' => 'xsicon xsicon-bolt',
                'xsicon xsicon-check' => 'xsicon xsicon-check',
                'xsicon xsicon-clock' => 'xsicon xsicon-clock',
                'xsicon xsicon-comment' => 'xsicon xsicon-comment',
                'xsicon xsicon-comment-solid' => 'xsicon xsicon-comment-solid',
				'xsicon xsicon-bars' => 'xsicon xsicon-bars',
				'xsicon xsicon-align-justify' => 'xsicon xsicon-align-justify',
				'xsicon xsicon-align-center' => 'xsicon xsicon-align-center',
				'xsicon xsicon-align-right' => 'xsicon xsicon-align-right',
				'xsicon xsicon-align-left' => 'xsicon xsicon-align-left',
				'xsicon xsicon-folder-solid' => 'xsicon xsicon-folder-solid',
				'xsicon xsicon-folder' => 'xsicon xsicon-folder',
				'xsicon xsicon-google-plus' => 'xsicon xsicon-google-plus',
				'xsicon xsicon-play' => 'xsicon xsicon-play',
				'xsicon xsicon-comments' => 'xsicon xsicon-comments',
				'xsicon xsicon-share' => 'xsicon xsicon-share',
				'xsicon xsicon-moon' => 'xsicon xsicon-moon',
				'xsicon xsicon-spinner' => 'xsicon xsicon-spinner',
				'xsicon xsicon-plug' => 'xsicon xsicon-plug',
				'xsicon xsicon-file' => 'xsicon xsicon-file',
				'xsicon xsicon-thumbtack' => 'xsicon xsicon-thumbtack',
		);

		return $icons;
	}

	/**
	 * Retrieve icons control default settings.
	 *
	 * Get the default settings of the icons control. Used to return the default
	 * settings while initializing the icons control.
	 *
	 * @since 1.0.0
	 * @access protected
	 *
	 * @return array Control default settings.
	 */

	protected function get_default_settings() {
		return [
			'options' => self::get_icons(),
		];
	}

	/**
	 * Render icons control output in the editor.
	 *
	 * Used to generate the control HTML in the editor using Underscore JS
	 * template. The variables for the class are available using `data` JS
	 * object.
	 *
	 * @since 1.0.0
	 * @access public
	 */

	public function content_template() {
		?>
		<div class="elementor-control-field">
			<label class="elementor-control-title">{{{ data.label }}}</label>
			<div class="elementor-control-input-wrapper">
				<select class="elementor-control-icon" data-setting="{{ data.name }}" data-placeholder="<?php esc_attr_e( 'Select Icon', 'vinkmag' ); ?>">
					<option value=""><?php esc_html_e( 'Select Icon', 'vinkmag' ); ?></option>
					<# _.each( data.options, function( option_title, option_value ) { #>
					<option value="{{ option_value }}">{{{ option_title }}}</option>
					<# } ); #>
				</select>
			</div>
		</div>
		<# if ( data.description ) { #>
		<div class="elementor-control-field-description">{{ data.description }}</div>
		<# } #>
		<?php
	}

}
