<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;

class Vinkmag_Post_Tab_Widget extends Widget_Base {

  public $base;

    public function get_name() {
        return 'vinazine-post-tab';
    }

    public function get_title() {
        return esc_html__( 'Post Tab', 'vinkmag' );
    }

    public function get_icon() { 
        return 'eicon-nav-menu';
    }

    public function get_categories() {
        return [ 'vinkmag-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_tab',
            [
                'label' => esc_html__('Post', 'vinkmag'),
            ]
        );
        $this->add_control(
         'shadow_opt',
         [
               'label' => esc_html__('Show shadow', 'vinkmag'),
               'type' => Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'vinkmag'),
               'label_off' => esc_html__('No', 'vinkmag'),
               'default' => 'yes',
         ]
      ); 


      $this->add_control(
        'block_title_show',
        [
            'label' => esc_html__('Show block title', 'vinkmag'),
            'type' => Controls_Manager::SWITCHER,
            'label_on' => esc_html__('Yes', 'vinkmag'),
            'label_off' => esc_html__('No', 'vinkmag'),
            'default' => 'yes',
        ]
    ); 

    $this->add_control(
        'block_title_style', [
            'label' => esc_html__('Block title style', 'vinkmag'),
            'type' => Vinkmag_Custom_Controls_Manager::IMAGECHOOSE,
            'default' => 'style1',
            'options' => require VINKMAG_EDITOR . '/elementor/widgets/widget-parts/helpers/block-title-styles-array.php',

            'condition' => [ 'block_title_show' => ['yes'] ]
        ]
    ); 

    $this->add_control(
        'block_title_markup',
        [
            'label'     =>esc_html__( 'Block title markup', 'vinkmag' ),
            'type'      => Controls_Manager::SELECT,
            'default'   => 'h2',
            'options'   => [
                    'h1'      =>esc_html__( 'H1', 'vinkmag' ),
                    'h2'      =>esc_html__( 'H2', 'vinkmag' ),
                    'h3'      =>esc_html__( 'H3', 'vinkmag' ),
                    'h4'      =>esc_html__( 'H4', 'vinkmag' ),
                    'h5'      =>esc_html__( 'H5', 'vinkmag' ),
                ],
            'condition' => [ 'block_title_show' => ['yes'] ]
        ]
    );

      $this->add_control(
         'block_title_text',
         [
               'label' => esc_html__('Block title', 'vinkmag'),
               'type' => Controls_Manager::TEXT,
               'default' => esc_html__( 'Post Slider', 'vinkmag' ),
               'condition' => [ 'block_title_show' => ['yes'] ]
         ]
      );

    
      $this->add_control(
            'block_title_color',
            [
               'label' => esc_html__('Block title color', 'vinkmag'),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'condition' => [ 'block_title_show' => ['yes'] ],
               'selectors' => [
                  '{{WRAPPER}} .title-text, {{WRAPPER}} .ts-title, {{WRAPPER}} .title-text' => 'color: {{VALUE}};',
               ],
            ]
      );

      $this->add_control(
            'block_title_background',
            [
               'label' => esc_html__('Title seperator background', 'vinkmag'),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'condition' => [ 'block_title_show' => ['yes'] ],
               'selectors' => [
                  '{{WRAPPER}} .title-text, {{WRAPPER}} .title-before, {{WRAPPER}} .title-after, {{WRAPPER}} .ts-title-item .topic-list, {{WRAPPER}} .owl-dots .owl-dot span' => 'background-color: {{VALUE}};',
               ],
            ]
      );

        $this->add_control(
          'post_count',
          [
            'label'         => esc_html__( 'Post count', 'vinkmag' ),
            'type'          => Controls_Manager::NUMBER,
            'default'       => '8',
          ]
        );
        $this->add_responsive_control(
			'thumbnail_height',
			[
				'label' =>esc_html__( 'Video height', 'vinkmag' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 565,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 465,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 365,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .post-video .item' => 'min-height: {{SIZE}}{{UNIT}};',
				],
			]
      );
      
        $this->add_control(
          'post_title_crop',
          [
            'label'         => esc_html__( 'Post title crop', 'vinkmag' ),
            'type'          => Controls_Manager::NUMBER,
            'default'       => '50',
          ]
        );
        $this->add_control(
            'post_format',
            [
                'label' =>esc_html__('Select Post Format', 'vinkmag'),
                'type'      => Vinkmag_Custom_Controls_Manager::SELECT2,
                'options' => [
					'standard'  =>esc_html__( 'Standard', 'vinkmag' ),
					'video' =>esc_html__( 'Video', 'vinkmag' ),
				],
				'default' => [],
                'label_block' => true,
                'multiple'  => true,
            ]
        );
        $this->add_control(
            'post_cats',
            [
                'label' =>esc_html__('Select Categories', 'vinkmag'),
                'type'      => Vinkmag_Custom_Controls_Manager::AJAXSELECT2,
                'options'   =>'category',
                'label_block' => true,
                'multiple'  => true,
            ]
        );
        $this->add_control(
         'show_author',
         [
             'label' => esc_html__('Show Author', 'vinkmag'),
             'type' => Controls_Manager::SWITCHER,
             'label_on' => esc_html__('Yes', 'vinkmag'),
             'label_off' => esc_html__('No', 'vinkmag'),
             'default' => 'yes',
         ]
     );

     $this->add_control(
         'show_author_image',
         [
             'label' => esc_html__('Show Author image', 'vinkmag'),
             'type' => Controls_Manager::SWITCHER,
             'label_on' => esc_html__('Yes', 'vinkmag'),
             'label_off' => esc_html__('No', 'vinkmag'),
             'default' => 'yes',
         ]
     );
     $this->add_control(
            'show_view_count',
            [
               'label' => esc_html__('Show view Count', 'vinkmag'),
               'type' => Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'vinkmag'),
               'label_off' => esc_html__('No', 'vinkmag'),
               'default' => 'yes',
            ]
      );

      $this->add_control(
            'show_date',
            [
                'label' => esc_html__('Show Date', 'vinkmag'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'vinkmag'),
                'label_off' => esc_html__('No', 'vinkmag'),
                'default' => 'yes',
            ]
        );

      $this->add_control(
            'show_cat',
            [
                'label' => esc_html__('Show Category', 'vinkmag'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'vinkmag'),
                'label_off' => esc_html__('No', 'vinkmag'),
                'default' => 'yes',
            ]
        );

      $this->add_control(
            'post_sortby',
            [
                'label'     =>esc_html__( 'Post sort by', 'vinkmag' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'latestpost',
                'options'   => [
                        'latestpost'      =>esc_html__( 'Latest posts', 'vinkmag' ),
                        'popularposts'    =>esc_html__( 'Popular posts', 'vinkmag' ),
                        'mostdiscussed'    =>esc_html__( 'Most discussed', 'vinkmag' ),
                    ],
            ]
        );

      $this->add_control(
            'post_order',
            [
                'label'     =>esc_html__( 'Post order', 'vinkmag' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'DESC',
                'options'   => [
                        'DESC'      =>esc_html__( 'Descending', 'vinkmag' ),
                        'ASC'       =>esc_html__( 'Ascending', 'vinkmag' ),
                    ],
            ]
        );

      $this->add_control(
         'xs_offset_enable',
            [
               'label' => esc_html__('Post skip', 'vinkmag'),
               'type' => Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'vinkmag'),
               'label_off' => esc_html__('No', 'vinkmag'),
               'default' => 'no',
               
            ]
      );
   
      $this->add_control(
         'xs_offset_item_num',
         [
         'label'         => esc_html__( 'Skip post count', 'vinkmag' ),
         'type'          => Controls_Manager::NUMBER,
         'default'       => '1',
         'condition' => [ 'xs_offset_enable' => 'yes' ]

         ]
      );  

      $this->end_controls_section();
    }

    protected function render( ) { 
        $settings = $this->get_settings();
        
        $arg = [
            'post_type'   =>  'post',
            'post_status' => 'publish',
            'order' => $settings['post_order'],
            'posts_per_page' => $settings['post_count'],
            'category__in' => $settings['post_cats'],

        ];

      if($settings['xs_offset_enable']=='yes'){
         $arg['offset'] = $settings['xs_offset_item_num'];
      }

        switch($settings['post_sortby']){
         case 'popularposts':
             $arg['meta_key'] = 'vinkmag_post_views_count';
             $arg['orderby'] = 'meta_value_num';
         break;
         case 'mostdiscussed':
             $arg['orderby'] = 'comment_count';
         break;
         default:
             $arg['orderby'] = 'date';
         break;
     }


        //$settings['show_author'] = 'no';
        $query = new \WP_Query( $arg ); ?>
        
        <?php if ( $query->have_posts() ) : ?>
            <div class="ts-grid-box watch-post mb-30  <?php echo esc_attr(($settings['shadow_opt'] == 'yes') ? '' : 'grid-no-shadow'); ?>">
            <?php require VINKMAG_THEME_DIR . '/template-parts/blogs/block-titles/block-title-init.php'; ?>
                <div class="row">
                    <div class="col-lg-7 col-md-6">
                        <div class="tab-content featured-post" id="nav-tabContent">
                            <?php $i = 0; while ($query->have_posts()) : $query->the_post(); $i++; ?>
                                <div class="tab-pane ts-overlay-style fade <?php echo esc_attr(($i == 1) ? 'show active' : ''); ?>" id="nav-post-tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($i); ?>" role="tabpanel" aria-labelledby="nav-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($i); ?>-tab">
                                    <?php require VINKMAG_THEME_DIR . '/template-parts/blogs/contents/content-style3-c.php'; ?>
                                </div>
                            <?php endwhile; 
                            wp_reset_query(); ?>
                        </div>
                    </div>
                    <div class="col-lg-5 col-md-6">
						<div class="nav post-list-box" id="nav-tab" role="tablist">
                            <?php $i = 0; while ($query->have_posts()) : $query->the_post(); $i++; ?>
                                <a class="nav-item nav-link <?php echo esc_attr(($i == 1) ? 'active' : ''); ?>" id="nav-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($i); ?>-tab" data-toggle="tab" href="#nav-post-tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($i); ?>" role="tab" aria-controls="nav-post-tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($i); ?>"
                                    aria-selected="true">
                                    <div class="post-content media">
                
                                    <?php
                                        echo wp_get_attachment_image(get_post_thumbnail_id($query->ID), array(185, 170), false, array(
                                            'alt'  =>  get_the_title(),
                                            'class' => 'd-flex'
                                        )); 
                                    ?>    
                                        <div class="media-body align-self-center">
                                            <h4 class="post-title">
                                               
                                                <?php echo esc_html(vinkmag_limited_title(get_the_title(),  $settings['post_title_crop'])); ?>
                                            </h4>
                                            <span class="post-date-info">
                                                <i class="xsicon xsicon-clock"></i>
                                                <?php echo get_the_date(); ?>
                                            </span>
                                        </div>
                                    </div>
                                </a>
                            <?php endwhile; ?>
                        </div>
                    </div>
                </div> 
            </div>
        <?php endif; ?>



      <?php  
    }
    protected function content_template() { }
}