<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;

class Vinkmag_Video_Post_Tab_Widget extends Widget_Base {

  public $base;

    public function get_name() {
        return 'vinazine-video-post-tab';
    }

    public function get_title() {
        return esc_html__( 'Video Post Tab', 'vinkmag' );
    }

    public function get_icon() { 
        return 'eicon-thumbnails-right';
    }

    public function get_categories() {
        return [ 'vinkmag-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_tab',
            [
                'label' => esc_html__('Post', 'vinkmag'),
            ]
        );
        $this->add_control(
            'section_title',
            [
                'label' => esc_html__('Block Title', 'vinkmag'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Post Slider', 'vinkmag' )
            ]
        );
        $this->add_control(
          'post_count',
          [
            'label'         => esc_html__( 'Post count', 'vinkmag' ),
            'type'          => Controls_Manager::NUMBER,
            'default'       => '8',
          ]
        );
        $this->add_control(
          'post_title_crop',
          [
            'label'         => esc_html__( 'Post title crop', 'vinkmag' ),
            'type'          => Controls_Manager::NUMBER,
            'default'       => '50',
          ]
        );
        $this->add_control(
            'title_margin',
            [
                'label' =>esc_html__( 'Title Margin', 'vinkmag' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .post-tab-list .post-content.media .post-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
    
        $this->add_control(
            'post_cats',
            [
                'label' =>esc_html__('Select Categories', 'vinkmag'),
                'type'      => Vinkmag_Custom_Controls_Manager::AJAXSELECT2,
                'options'   =>'category',
                'label_block' => true,
                'multiple'  => true,
            ]
        );
        $this->add_control(
            'show_date',
            [
                'label' => esc_html__('Show Date', 'vinkmag'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'vinkmag'),
                'label_off' => esc_html__('No', 'vinkmag'),
                'default' => 'no',
            ]
        );
        $this->add_control(
            'date_text_color',
            [
                'label' => esc_html__('Date Text color', 'vinkmag'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .post-content.media .post-date' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'show_cat',
            [
                'label' => esc_html__('Show Category', 'vinkmag'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'vinkmag'),
                'label_off' => esc_html__('No', 'vinkmag'),
                'default' => 'no',
            ]
        );
       
        $this->add_control(
            'cat_margin',
            [
                'label' =>esc_html__( 'Category  Margin', 'vinkmag' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .post-tab-list .post-content.media .post-cat' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->add_control(
            'post_sortby',
            [
                'label'     =>esc_html__( 'Post sort by', 'vinkmag' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'latestpost',
                'options'   => [
                        'latestpost'      =>esc_html__( 'Latest posts', 'vinkmag' ),
                        'popularposts'    =>esc_html__( 'Popular posts', 'vinkmag' ),
                        'mostdiscussed'    =>esc_html__( 'Most discussed', 'vinkmag' ),
                    ],
            ]
        );
        $this->add_control(
            'post_order',
            [
                'label'     =>esc_html__( 'Post order', 'vinkmag' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'DESC',
                'options'   => [
                        'DESC'      =>esc_html__( 'Descending', 'vinkmag' ),
                        'ASC'       =>esc_html__( 'Ascending', 'vinkmag' ),
                    ],
            ]
        );

      $this->add_control(
         'xs_offset_enable',
            [
               'label' => esc_html__('Post skip', 'vinkmag'),
               'type' => Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'vinkmag'),
               'label_off' => esc_html__('No', 'vinkmag'),
               'default' => 'no',
               
            ]
      );
   
      $this->add_control(
         'xs_offset_item_num',
         [
         'label'         => esc_html__( 'Skip post count', 'vinkmag' ),
         'type'          => Controls_Manager::NUMBER,
         'default'       => '1',
         'condition' => [ 'xs_offset_enable' => 'yes' ]

         ]
      );

      $this->add_responsive_control(
        'main_border_radius',
        [
            'label' => esc_html__( 'Video Border Radius', 'vinkmag' ),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px','%'],
            'selectors' => [
                '{{WRAPPER}} .video-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]
    );
      $this->add_responsive_control(
        'list_border_radius',
        [
            'label' => esc_html__( 'List Background Border Radius', 'vinkmag' ),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px','%'],
            'selectors' => [
                '{{WRAPPER}} .video-tab-list' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]
    );
      $this->add_responsive_control(
        'item_border_radius',
        [
            'label' => esc_html__( 'List Item Border Radius', 'vinkmag' ),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px','%'],
            'selectors' => [
                '{{WRAPPER}} .video-tab-list .post-content.media img.sidebar-img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]
    );

     

      $this->add_group_control(
        Group_Control_Border::get_type(),
            [
                'name' => 'content_border',
                'label' => __( 'Content Border', 'vinkmag' ),
                'selector' => '{{WRAPPER}} .post-content.media',
            ]
        );
   
      $this->add_responsive_control(
        'thumbnail_height',
            [
                'label' =>esc_html__( 'Thumbnail Height', 'vinkmag' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 55,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 55,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 55,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .video-tab-list .post-content.media img.sidebar-img' => 'min-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'thumb_border_radius',
            [
                'label' => esc_html__( 'Thumbnail Border Radius', 'vinkmag' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','%'],
                'selectors' => [
                    '{{WRAPPER}} .video-tab-list .post-content.media img.sidebar-img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->end_controls_section();
    }

    protected function render( ) { 
        $settings = $this->get_settings();

        $show_date  = (isset($settings['show_date'])) 
						? $settings['show_date'] 
                        : vinkmag_option('show_date', 'no' );
                        
        $show_cat	= (isset($settings['show_cat'])) 
						? $settings['show_cat'] 
                      : vinkmag_option( 'show_cat', 'no' );

        $crop		= (isset($settings['post_title_crop']))
						? $settings['post_title_crop']
                        : 50;

        $thumb 					= [600, 398];
        $arg = [
            'post_type'   =>  'post',
            'post_status' => 'publish',
            'order' => $settings['post_order'],
            'posts_per_page' => $settings['post_count'],
            'category__in' => $settings['post_cats'],
            'tax_query' => [
                [
                    'taxonomy' => 'post_format',
                    'field' => 'slug',
                    'terms' => 'post-format-video'
                ]
            ]
        ];

         if( $settings['xs_offset_enable']=='yes' ) {

            $arg['offset'] = $settings['xs_offset_item_num'];
         
         }

        switch($settings['post_sortby']){
         case 'popularposts':
             $arg['meta_key'] = 'vinkmag_post_views_count';
             $arg['orderby'] = 'meta_value_num';
         break;
         case 'mostdiscussed':
             $arg['orderby'] = 'comment_count';
         break;
         default:
             $arg['orderby'] = 'date';
         break;
     }
        $settings['show_author'] = 'no';
        $query = new \WP_Query( $arg ); ?>
        
        <?php if ( $query->have_posts() ) : ?>
            <div class="row">
                <div class="col-lg-8 pr-0">
                    <div class="tab-content clearfix">
                        <?php $i = 0; while ($query->have_posts()) : $query->the_post(); $i++; ?>
                            <div class="tab-pane fade <?php echo esc_attr(($i == 1) ? 'in active' : ''); ?>" id="video-tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($i); ?>">
                                <div class="video-item" style="background-image: url(<?php echo esc_url(vinkmag_post_thumbnail(get_the_ID(), $thumb[0], $thumb[1])); ?>)">
                                    <?php require VINKMAG_THEME_DIR . '/template-parts/blogs/contents/content-style3-d.php'; ?>
                                </div>
                            </div>
                        <?php endwhile; 
                        wp_reset_query(); ?>
                    </div>
                </div>
                
                <div class="col-lg-4 pl-0">
                    <div class="video-tab-list bg-dark-item video-tab-scrollbar" id="video-tab-scrollbar">
                        <ul class="nav nav-pills post-tab-list">
                        <?php $i = 0; while ($query->have_posts()) : $query->the_post(); $i++; ?>
                            <li class="<?php echo esc_attr(($i == 1) ? 'active' : ''); ?>">
                                <a href="#video-tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($i); ?>" data-toggle="tab">
                                    <div class="post-content media">
                                        <?php
                                            echo wp_get_attachment_image(get_post_thumbnail_id($query->ID), array(185, 170), false, array(
                                                'alt'  =>  get_the_title(),
                                                'class' => 'd-flex sidebar-img'
                                            )); 
                                        ?>
                                        
                                        <div class="media-body align-self-center">
                                        <?php if($show_cat == 'yes'): ?> 
                                            <?php $cat = get_the_category(); ?>
                                            <a class="post-cat" href="<?php echo get_category_link($cat[0]->term_id); ?>"
                                                style="<?php echo esc_attr(vinkmag_cat_style($cat[0]->term_id)); ?>"
                                                >
                                                <?php echo get_cat_name($cat[0]->term_id); ?>
                                            </a>
                                        <?php endif; ?>

                                            <h4 class="post-title">
                                                <?php echo esc_html(vinkmag_limited_title(get_the_title(), $crop)); ?>
                                            </h4>

                                            <?php if($show_date == 'yes'): ?>
                                            <p class="post-date"><i class="xsicon xsicon-clock"></i> <?php echo get_the_date(); ?> </p>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </a>
                            </li>
                        <?php endwhile; ?>
                        </ul>
                    </div>
                </div>
            </div>
        <?php endif; ?>

      <?php  
    }
    protected function content_template() { }
}