<?php

// shorthand contants
// ------------------------------------------------------------------------
define('VINKMAG_THEME', 'Vinkmag WordPress Theme');
define('VINKMAG_VERSION', '4.0');
define('VINKMAG_MINWP_VERSION', '5.3');


// shorthand contants for theme assets url
// ------------------------------------------------------------------------
define('VINKMAG_THEME_URI', get_template_directory_uri());
define('VINKMAG_IMG', VINKMAG_THEME_URI . '/assets/images');
define('VINKMAG_CSS', VINKMAG_THEME_URI . '/assets/css');
define('VINKMAG_JS', VINKMAG_THEME_URI . '/assets/js');


// shorthand contants for theme assets directory path
// ----------------------------------------------------------------------------------------
define('VINKMAG_THEME_DIR', get_template_directory());
define('VINKMAG_IMG_DIR', VINKMAG_THEME_DIR . '/assets/images');
define('VINKMAG_CSS_DIR', VINKMAG_THEME_DIR . '/assets/css');
define('VINKMAG_JS_DIR', VINKMAG_THEME_DIR . '/assets/js');

define('VINKMAG_CORE', VINKMAG_THEME_DIR . '/core');
define('VINKMAG_COMPONENTS', VINKMAG_THEME_DIR . '/components');
define('VINKMAG_EDITOR', VINKMAG_COMPONENTS . '/editor');
define('VINKMAG_EDITOR_ELEMENTOR', VINKMAG_EDITOR . '/elementor');
define('VINKMAG_EDITOR_GUTENBERG', VINKMAG_EDITOR . '/gutenberg');
define('VINKMAG_INSTALLATION', VINKMAG_CORE . '/installation-fragments');
define('VINKMAG_REMOTE_CONTENT', esc_url('https://content.xpeedstudio.com/demo-content/vinkmag'));
define('VINKMAG_LIVE_URL', esc_url('https://demo.xpeedstudio.com/vinkmag'));
define( 'VINKMAG_UNYSON_URL', esc_url( 'https://demo.xpeedstudio.com/global-plugin' ) );


// set up the content width value based on the theme's design
// ----------------------------------------------------------------------------------------
if (!isset($content_width)) {
    $content_width = 800;
}


// set up theme default and register various supported features.
// ----------------------------------------------------------------------------------------

function vinkmag_action_setup() {

    // make the theme available for translation
    $lang_dir = VINKMAG_THEME_DIR . '/languages';
    load_theme_textdomain('vinkmag', $lang_dir);

    // add support for post formats
    add_theme_support('post-formats', [
        'standard', 'video',
    ]);

    // add support for automatic feed links
    add_theme_support('automatic-feed-links');

    // let WordPress manage the document title
    add_theme_support('title-tag');

    // add support for post thumbnails
    add_theme_support('post-thumbnails');

    // hard crop center center
    set_post_thumbnail_size(850, 560, ['center', 'center']);
    add_image_size( 'vinkmag-medium', 600, 398, array( 'center', 'center' ) );
    add_image_size( 'vinkmag-small', 455, 300, array( 'center', 'center' ) );
    add_image_size( 'vinkmag-search-thumb', 850, 400, array( 'center', 'center' ) );

    // register navigation menus
    register_nav_menus(
        [
            'primary' => esc_html__('Primary menu', 'vinkmag'),
            'top' => esc_html__('Top menu', 'vinkmag'),
            'footer' => esc_html__('Footer menu', 'vinkmag'),
        ]
    );

    // HTML5 markup support for search form, comment form, and comments
    add_theme_support('html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ));

    //Wooocmmemrce support

	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-lightbox' );
    add_theme_support( 'wc-product-gallery-slider' );

    /*
    * Enable support for wide alignment class for Gutenberg blocks.
    */
    add_theme_support( 'align-wide' );
    add_theme_support( 'editor-styles' );
    add_theme_support( 'wp-block-styles' );
}
add_action('after_setup_theme', 'vinkmag_action_setup');



// hooks for unyson framework
// ----------------------------------------------------------------------------------------
function vinkmag_filter_framework_customizations_path($rel_path) {
    return '/components';
}
add_filter('fw_framework_customizations_dir_rel_path', 'vinkmag_filter_framework_customizations_path');


function vinkmag_action_remove_fw_settings() {
    remove_submenu_page( 'themes.php', 'fw-settings' );
}
add_action( 'admin_menu', 'vinkmag_action_remove_fw_settings', 999 );


// include the init.php
// ----------------------------------------------------------------------------------------
require_once( VINKMAG_CORE . '/init.php');

// include editor files
// ----------------------------------------------------------------------------------------
require_once( VINKMAG_COMPONENTS . '/editor/elementor/elementor.php'); // elementor widgets

add_action('enqueue_block_editor_assets', 'vinkmag_action_enqueue_block_editor_assets' );
function vinkmag_action_enqueue_block_editor_assets() {
    wp_enqueue_style( 'vinkmag-fonts', vinkmag_google_fonts_url(['Arimo:400,400i,700,700i', 'Heebo:400,500,700,800,900', 'Merriweather:400,400i,700,700i,900,900i']), null, VINKMAG_VERSION );
    wp_enqueue_style( 'vinkmag-gutenberg-editor-font-awesome-styles', VINKMAG_CSS . '/font-awesome.min.css', null, VINKMAG_VERSION );
    wp_enqueue_style( 'vinkmag-gutenberg-editor-customizer-styles', VINKMAG_CSS . '/gutenberg-editor-custom.css', null, VINKMAG_VERSION );
    wp_enqueue_style( 'vinkmag-gutenberg-editor-styles', VINKMAG_CSS . '/gutenberg-custom.css', null, VINKMAG_VERSION );
    wp_enqueue_style( 'vinkmag-gutenberg-blog-styles', VINKMAG_CSS . '/blog.css', null, VINKMAG_VERSION );
}

// dark light mode
function vinkmag_darklight_mode(){
    $style_darklight_mode = vinkmag_option('style_darklight_mode');
    if($style_darklight_mode == 'yes'){
    ?>
        <div class="color_swicher change-mode">
            <div class="switch_container">
                <i class="xsicon xsicon-sun"></i>
                <i class="xsicon xsicon-moon"></i>
            </div>
        </div>

    <?php
    }
}
add_action('wp_body_open', 'vinkmag_darklight_mode');

// Optimization Option
// for optimization dequeue styles
add_action( 'wp_enqueue_scripts', 'vinkmag_remove_unused_css_files', 9999 );
function vinkmag_remove_unused_css_files() {
    $fontawesome = vinkmag_option( 'fontawesome_off', 'no' );
    $blocklibrary = vinkmag_option( 'wp_block_library_off', 'no' );;
    $dashicons = vinkmag_option( 'dashicons_off', 'no' );
    $elementoricons = vinkmag_option( 'elementor_icons_off', 'no' );
    $wpreview = vinkmag_option( 'wur_css_off', 'no' );

    //Unyson css
    wp_dequeue_style('fw-ext-builder-frontend-grid');
    wp_deregister_style( 'fw-ext-builder-frontend-grid' );
    wp_dequeue_style('fw-ext-forms-default-styles');
    wp_deregister_style( 'fw-ext-forms-default-styles' );

    //Gutenberg css
    wp_dequeue_style('vinkmag-gutenberg-custom');
    wp_deregister_style( 'vinkmag-gutenberg-custom' );
    //line awesome from mega menu css
    wp_dequeue_style('line-awesome');
    wp_deregister_style( 'line-awesome' );

    // dequeue wp-review styles file
    if($wpreview == 'no'){
        wp_dequeue_style( 'wur_content_css' );
        wp_deregister_style( 'wur_content_css' );
    }
    if($dashicons == 'no'){
        // Don't remove it in the backend
        if ( is_admin() || current_user_can( 'manage_options' ) ) {
            return;
        }
        wp_dequeue_style( 'dashicons' );
    }

    // dequeue fontawesome icons file
    if($fontawesome == 'no'){
        wp_dequeue_style( 'font-awesome' );
	    wp_deregister_style( 'font-awesome' );
        wp_dequeue_style( 'font-awesome-5-all' );
        wp_deregister_style( 'font-awesome-5-all' );
        wp_dequeue_style( 'font-awesome-4-shim' );
        wp_deregister_style( 'font-awesome-4-shim' );
        wp_dequeue_style( 'fontawesome-five-css' );
        wp_dequeue_script( 'font-awesome-4-shim' );
    }

    // dequeue block-library file
    if($blocklibrary == 'no'){
        wp_dequeue_style( 'wp-block-library' );
        wp_dequeue_style( 'wp-block-library-theme' );
        wp_dequeue_style( 'wc-blocks-style' );
		wp_deregister_style( 'wc-blocks-style' );
        wp_dequeue_script( 'jquery-blockui' );
        wp_deregister_script( 'jquery-blockui' );
    }

   if($elementoricons == 'no'){
        // Don't remove it in the backend
        if ( is_admin() || current_user_can( 'manage_options' ) ) {
            return;
        }
        wp_dequeue_style( 'elementor-animations' );
        wp_dequeue_style( 'elementor-icons' );
        wp_deregister_style( 'elementor-icons' );        
    }	
}

/* disable option for font awesome icons from elementor editor */
add_action( 'elementor/frontend/after_register_styles',function() {
    $fontawesome = 'no';
    if($fontawesome == 'no'){
        foreach( [ 'solid', 'regular', 'brands' ] as $style ) {
            wp_deregister_style( 'elementor-icons-fa-' . $style );
        }
    }
    
}, 20 );

/* disable option for font awesome icons from elementor editor */
add_filter('elementor/icons_manager/native', function($icons){
    $fontawesome = 'no';
    if($fontawesome == 'no'){
        unset($icons['fa-regular']);
        unset($icons['fa-solid']);
        unset($icons['fa-brands']);        
    }

    return $icons;
});

//meta description
function vinkmag_meta_des_viewport(){
    ?>
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=5">
    <meta name="description" content="<?php if ( is_single() ) {
    single_post_title('', true); 
        } else {
        bloginfo('name'); echo " - "; bloginfo('description');
        }
        ?>" />
    <?php
}
add_action('wp_head', 'vinkmag_meta_des_viewport', 1);


// content security policy(CSP)
header("Content-Security-Policy: script-src 'self' 'unsafe-inline' 'unsafe-eval' https: data:");